/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AlienCommandList.h"

#include <algorithm>

//__________________________________________________________________
const AlienCommand& AlienCommandList::front( void ) const
{ return front_; }

//__________________________________________________________________
bool AlienCommandList::append( const AlienCommand& command )
{
    Debug::Throw( "AlienCommandList::append.\n" );

    if( set_.find( command ) != set_.end() ) return false;

    const bool empty( set_.isEmpty() );
    set_.insert( command );

    // find list matching command priority
    if( command.priority() >= list_.size() )
    { list_.resize( command.priority()+1 ); }

    // append
    list_[command.priority()] << command;

    // store
    if( empty ) front_ = command;

    return true;

}

//__________________________________________________________________
bool AlienCommandList::removeFirst( void )
{
    Debug::Throw( "AlienCommandList::removeFirst.\n" );
    set_.remove( front_ );
    Q_ASSERT( list_.size() > front_.priority() );
    Q_ASSERT( !list_[front_.priority()].empty() );
    Q_ASSERT( list_[front_.priority()].front() == front_ );
    list_[front_.priority()].removeFirst();

    // advance to next
    auto iter( std::find_if( list_.begin(), list_.end(), NonEmptyFTor() ) );
    if( iter != list_.end() ) front_ = iter->front();

    return true;
}

//__________________________________________________________________
bool AlienCommandList::abort( const AlienCommand& command )
{
    Debug::Throw( "AlienCommandList::abort.\n" );
    if( command == front_ || !set_.contains( command ) ) return false;

    // remove from set
    set_.remove( command );
    auto& commands( list_[command.priority()] );
    auto iter = std::find( commands.begin(), commands.end(), command );
    Q_ASSERT( iter != commands.end() );
    commands.erase( iter );
    return true;

}
