/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "JobCollection.h"
#include "XmlDef.h"
#include "XmlDocument.h"

//________________________________________________________
bool JobCollection::read( const File& file )
{

    // parse the file
    QFile in( file );

    // parse the file
    XmlDocument document;
    {
        QFile qfile( file );
        if( !document.setContent( &qfile ) )
        {
            Debug::Throw() << document.error() << endl;
            return false;
        }
    }

    // look for relevant element
    QDomNodeList topNodes = document.elementsByTagName( Xml::Realm );
    if( topNodes.isEmpty() ) return false;
    for(QDomNode node = topNodes.at(0).firstChild(); !node.isNull(); node = node.nextSibling() )
    {
        QDomElement element = node.toElement();
        if( element.isNull() ) continue;

        QString tagName( element.tagName() );
        if( tagName == Xml::JobSet ) add( JobSet( element ) );

    }

    return true;

}

//________________________________________________________
bool JobCollection::write( const File& file ) const
{

    // check history file
    QFile out( file );

    // create document and read
    XmlDocument document;
    {
        QFile qtfile( file );
        document.setContent( &qtfile );
    }

    // create document
    QDomElement top( document.createElement( Xml::Realm ) );

    // add job sets
    for( const auto& jobSet:jobSets_ )
    { top.appendChild( jobSet.domElement( document )  ); }

    // append top node to document and write
    document.replaceChild( top );
    {
        QFile qfile( file );
        if( !qfile.open( QIODevice::WriteOnly ) ) return false;
        qfile.write( document.toByteArray() );
    }

    return true;

}
