/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "JobListDialog.h"

#include "TreeView.h"
#include "XmlOptions.h"

#include <QHeaderView>
#include <QLabel>
#include <QLayout>
#include <QScrollBar>

//____________________________________________________________________________
JobListDialog::JobListDialog( QWidget* parent, const JobModel::List& jobs ):
    QuestionDialog( parent ),
    model_( this )
{

    Debug::Throw( "JobListDialog::JobListDialog.\n" );

    TreeView* treeView( new TreeView( this ) );
    treeView->setSelectionMode( QAbstractItemView::NoSelection );

    model_.add( jobs );
    model_.sort( Job::Id, Qt::DescendingOrder );

    // setup list
    treeView->setModel( &model_ );
    treeView->setMask( 1<<Job::Id|1<<Job::Status|1<<Job::Command );
    treeView->header()->setSortIndicator( Job::Id, Qt::AscendingOrder );

    treeView->setMinimumSize( QSize(
        treeView->sizeHint().width(),
        ( treeView->fontMetrics().height() + 2*treeView->itemMargin() )*5 + 10 ) );

    setDetails( treeView );

}
