/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "JobTraceSyntaxHighlighter.h"

#include "Color.h"
#include "Debug.h"
#include "Singleton.h"
#include "XmlOptions.h"
#include "Color.h"

//__________________________________________________________
JobTraceSyntaxHighlighter::JobTraceSyntaxHighlighter( QTextDocument* parent ):
    QSyntaxHighlighter( parent ),
    Counter( "JobTraceSyntaxHighlighter" ),
    regExp_( "\\[(proc|state|submit|trace)\\s*\\]:" )
{
    Debug::Throw( "JobTraceSyntaxHighlighter::JobTraceSyntaxHighlighter.\n" );
    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
    _updateConfiguration();
}

//__________________________________________________________
void JobTraceSyntaxHighlighter::highlightBlock( const QString & text )
{
    // match regexp
    int position( text.indexOf( regExp_ ) );
    if( position >= 0 )
    {
        const int length( regExp_.matchedLength() );
        const QString tag( regExp_.cap(1) );
        QColor color;

        if( tag == "trace" ) color = traceColor_;
        if( tag == "state" ) color = stateColor_;
        else if( tag == "proc" ) color = procColor_;
        else if( tag == "submit" ) color = submitColor_;
        if( !color.isValid() ) return;

        QTextCharFormat format;
        format.setForeground( color );
        setFormat( 0, length + position, format );
    }

}

//__________________________________________________________
void JobTraceSyntaxHighlighter::_updateConfiguration( void )
{
    Debug::Throw( "JobTraceSyntaxHighlighter::_updateConfiguration.\n" );
    traceColor_ = XmlOptions::get().get<Base::Color>( "JOB_TRACE_TRACE_COLOR" );
    stateColor_ = XmlOptions::get().get<Base::Color>( "JOB_TRACE_STATE_COLOR" );
    procColor_ = XmlOptions::get().get<Base::Color>( "JOB_TRACE_PROC_COLOR" );
    submitColor_ = XmlOptions::get().get<Base::Color>( "JOB_TRACE_SUBMIT_COLOR" );
}
