/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LogDialog.h"

#include "Debug.h"
#include "IconNames.h"
#include "IconEngine.h"
#include "LogWidget.h"

#include <QShortcut>

//_____________________________________________________________
LogDialog::LogDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{
    Debug::Throw("LogDialog::LogDialog.\n" );
    setWindowTitle( "Log Information - Gridwatch" );
    setOptionName( "LOG_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    // editor
    editor_ = new LogWidget( this );
    editor_->setOptionName( "LOG_WIDGET" );

    TextEditor::Container* container = new TextEditor::Container( this, editor_ );
    mainLayout().addWidget( container );

    // clear button
    QPushButton *button = new QPushButton( IconEngine::get( IconNames::Clear ), "Clear", this );
    connect( button, SIGNAL(clicked()), editor_, SLOT(clear()) );
    buttonLayout().insertWidget(1, button );

    // ok button
    connect( &okButton(), SIGNAL(pressed()), SLOT(close()) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT(close()) );

}

//_____________________________________________________________
void LogDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "LogDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
