/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Menu.h"

#include "Debug.h"
#include "DebugMenu.h"
#include "Application.h"
#include "JobInformationDialog.h"
#include "MainWindow.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <QMenu>

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu\n" );

    // generic menu
    QMenu *menu;

    // application and top widget
    Application& application( *static_cast<Application*>(Singleton::get().application()) );
    MainWindow& mainWindow( *static_cast<MainWindow*>(topLevelWidget()) );

    // file menu
    menu = addMenu( tr( "File" ) );
    menu->addAction( &mainWindow.addFrameAction() );
    menu->addAction( &mainWindow.removeFrameAction() );
    menu->addAction( &mainWindow.connectAction() );
    menu->addAction( &mainWindow.updateAction() );
    menu->addAction( &mainWindow.clearAction() );
    menu->addSeparator();
    menu->addAction( &application.closeAction() );

    // windows menu
    windowsMenu_ = addMenu( tr( "Windows" ) );
    connect( windowsMenu_, SIGNAL(aboutToShow()), this, SLOT(_updateWindowsMenu()) );

    // tools
    menu = addMenu( tr( "Tools" ) );
    menu->addAction( &mainWindow.defaultUserAction() );
    menu->addAction( &mainWindow.userListAction() );

    // Settings menu
    menu = addMenu( tr( "Settings" ) );
    menu->addAction( &mainWindow.toggleLogAction() );
    menu->addAction( &mainWindow.hideKilledJobsAction() );
    menu->addAction( &mainWindow.toggleSummaryAction() );
    menu->addSeparator();
    menu->addAction( &application.configurationAction() );

    // create help menu
    menu = addMenu( tr( "Help" ) );
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

}

//____________________________________________________________________
void Menu::_updateWindowsMenu( void )
{

    Debug::Throw( "Menu::_updateWindowsMenu.\n" );

    // clear menu
    windowsMenu_->clear();

    // standard actions
    MainWindow& mainWindow( *static_cast<MainWindow*>(topLevelWidget()) );
    windowsMenu_->addAction( &mainWindow.commandListAction() );
    windowsMenu_->addAction( &mainWindow.logAction() );
    windowsMenu_->addSeparator();

    // get job information dialogs
    QAction* action;
    const Base::KeySet<JobInformationDialog> dialogs( &mainWindow );
    for( const auto& dialog:dialogs )
    {
        QString buffer = QString( tr( "Job %1" ) ).arg( dialog->job().id() );
        windowsMenu_->addAction( action = new QAction( buffer, windowsMenu_ ) );
        connect( action, SIGNAL(triggered()), dialog, SLOT(uniconify()) );
    }

    if( !dialogs.empty() )
    {
        windowsMenu_->addSeparator();
        windowsMenu_->addAction( &mainWindow.closeJobDialogsAction() );
    }

    return;

}
