#ifndef OpenFileDialog_h
#define OpenFileDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"
#include "File.h"

#include <QRadioButton>

class OpenWithComboBox;

class OpenFileDialog: public CustomDialog
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    enum Command
    {
        OpenWith = 1<<0,
        SaveAs = 1<<1,
        Any = OpenWith|SaveAs
    };

    Q_DECLARE_FLAGS( Commands, Command )

    //* constructor
    OpenFileDialog( QWidget*, File, Commands = Any );

    //*@name accessors
    //@{

    //* true if command is valid
    bool isOpenWithCommandValid( void ) const;

    //* true if command is default
    bool isOpenWithCommandDefault( void ) const;

    //* get command
    QString openWithCommand( void ) const;

    //* command
    Command command( void )
    { return openWithRadioButton_->isChecked() ? OpenWith : SaveAs; }

    //@}

    //*@name modifiers
    //@{

    //* set command
    void setCommand( const Command& command )
    { openWithRadioButton_->setChecked( command == OpenWith ); }

    //@}

    protected Q_SLOTS:

    //* save commands added to combobox
    void _saveCommands( void );

    private:

    OpenWithComboBox* comboBox_ = nullptr;
    QRadioButton* openWithRadioButton_ = nullptr;
    QRadioButton* saveAsRadioButton_ = nullptr;

};

Q_DECLARE_OPERATORS_FOR_FLAGS( OpenFileDialog::Commands )

#endif
